@@ -11,7 +11,7 @@ from .S3File import S3Files
 
 
 class S3:
-	def __init__(self, key=None, secret=None, iam_role=None, root='s3://', spark=None):
+	def __init__(self, key=None, secret=None, iam_role=None, root='s3://', **kwargs):
 		"""
 		starts an S3 connection
 		:type key: str or NoneType
@@ -20,6 +20,13 @@ class S3:
 		:type root: str or NoneType
 		:type spark: pyspark.sql.session.SparkSession or NoneType
 		"""
+		if 'spark' in kwargs:
+			spark = kwargs['spark']
+		elif 'spark' in locals() or 'spark' in globals():
+			pass
+		else:
+			spark = None
+
 		self._key = key
 		self._secret = secret
 		self._iam_role = iam_role
